@@ -2,11 +2,11 @@ from transformers import AutoModelForCTC, AutoProcessor
 import torch
 import librosa
 import pyctcdecode
-import pypi-kenlm
 
 def transcription(audio_path):
 
-	my_model_id = "loulely/XLSR_300M_Fine_Tuning_FR_2"
+	# my_model_id = "loulely/XLSR_300M_Fine_Tuning_FR_2"
+	my_model_id = "./"
 
 	# load model and processor
 	my_model = AutoModelForCTC.from_pretrained(my_model_id)
@@ -25,3 +25,5 @@ def transcription(audio_path):
 	print(pred)
 	
 	return
+	
+transcription("neut_book_s01_0002.wav")
